@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
 // Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
@@ -6,8 +6,8 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use super::{operation_id, register::RegisterRead, Error, OperationId, QueryResponse, Result};
-use crate::types::ChunkAddress;
+use super::{operation_id, register::RegisterQuery, Error, OperationId, QueryResponse, Result};
+use crate::types::{ChunkAddress, ReplicatedDataAddress as DataAddress};
 use serde::{Deserialize, Serialize};
 use xor_name::XorName;
 
@@ -29,7 +29,7 @@ pub enum DataQuery {
     /// [`Register`] read operation.
     ///
     /// [`Register`]: crate::types::register::Register
-    Register(RegisterRead),
+    Register(RegisterQuery),
 }
 
 impl DataQuery {
@@ -52,6 +52,14 @@ impl DataQuery {
         }
     }
 
+    /// Returns the address of the data
+    pub fn address(&self) -> DataAddress {
+        match self {
+            DataQuery::GetChunk(address) => DataAddress::Chunk(*address),
+            DataQuery::Register(read) => DataAddress::Register(read.dst_address()),
+        }
+    }
+
     /// Retrieves the operation identifier for this response, use in tracking node liveness
     /// and responses at clients.
     /// Must be the same as the query response
