@@ -1,4 +1,4 @@
-// Copyright 2021 MaidSafe.net limited.
+// Copyright 2022 MaidSafe.net limited.
 //
 // This SAFE Network Software is licensed to you under The General Public License (GPL), version 3.
 // Unless required by applicable law or agreed to in writing, the SAFE Network Software distributed
@@ -48,7 +48,15 @@ impl RegisterAddress {
         }
     }
 
+    /// This is a unique identifier of the Register,
+    /// since it also encodes the Public | Private scope,
+    /// as well as the tag of the Address.
+    pub fn id(&self) -> Result<XorName> {
+        Ok(XorName::from_content(self.encode_to_zbase32()?.as_bytes()))
+    }
+
     /// Returns the name.
+    /// This is not a unique identifier.
     pub fn name(&self) -> &XorName {
         match self {
             Self::Public { ref name, .. } | Self::Private { ref name, .. } => name,
